@@ -27,8 +27,8 @@ DEBUG_BUILD=0
 ASAN_BUILD=0
 CREATE_STARTUP_SCRIPT=1
 ENABLE_FREI0R=1
-FREI0R_HEAD=1
-FREI0R_REVISION=
+FREI0R_HEAD=0
+FREI0R_REVISION="36e7da5d9e1f8b8cac9e97e204db1c5834fee580"
 ENABLE_MOVIT=1
 SUBDIRS=
 MOVIT_HEAD=0
@@ -43,7 +43,7 @@ LIBOPUS_HEAD=0
 LIBOPUS_REVISION="v1.4"
 ENABLE_SWH_PLUGINS=1
 FFMPEG_HEAD=0
-FFMPEG_REVISION="origin/release/6.1"
+FFMPEG_REVISION="origin/release/7.0"
 FFMPEG_SUPPORT_H264=1
 FFMPEG_SUPPORT_H265=1
 FFMPEG_SUPPORT_JACK=1
@@ -59,6 +59,7 @@ FFMPEG_SUPPORT_QSV=1
 FFMPEG_SUPPORT_DAV1D=1
 FFMPEG_SUPPORT_AOM=1
 FFMPEG_SUPPORT_WEBP=1
+FFMPEG_SUPPORT_SVTAV1=1
 FFMPEG_SUPPORT_VMAF=1
 FFMPEG_ADDITIONAL_OPTIONS=
 ENABLE_VIDSTAB=1
@@ -80,18 +81,20 @@ ENABLE_ZIMG=1
 ZIMG_HEAD=0
 ZIMG_REVISION="51c3c7f750c2af61955377faad56e3ba1b03589f"
 DAV1D_HEAD=0
-DAV1D_REVISION="1.3.0"
+DAV1D_REVISION="1.4.2"
 AOM_HEAD=0
 AOM_REVISION="v3.8.0"
+SVTAV1_HEAD=0
+SVTAV1_REVISION="v2.1.0"
 VMAF_HEAD=0
-VMAF_REVISION="v2.3.1"
+VMAF_REVISION="v3.0.0"
 ENABLE_GLAXNIMATE=1
 GLAXNIMATE_HEAD=0
-GLAXNIMATE_REVISION="0.5.4"
+GLAXNIMATE_REVISION="origin/v0.5.4"
 ENABLE_GOPRO2GPX=1
 ENABLE_OPENCV=1
 OPENCV_HEAD=0
-OPENCV_REVISION="4.7.0"
+OPENCV_REVISION="4.9.0"
 ENABLE_LIBWEBP=1
 LIBWEBP_HEAD=0
 LIBWEBP_REVISION="v1.3.2"
@@ -100,10 +103,10 @@ LIBSPATIALAUDIO_HEAD=1
 LIBSPATIALAUDIO_REVISION=
 
 PYTHON_VERSION_DEFAULT=3.8
-PYTHON_VERSION_DARWIN=3.10
+PYTHON_VERSION_DARWIN=3.11
 
 QT_VERSION_DEFAULT=6.4.3
-QT_VERSION_DARWIN=6.5.3
+QT_VERSION_DARWIN=6.7.1
 
 # QT_INCLUDE_DIR="$(pkg-config --variable=prefix QtCore)/include"
 QT_INCLUDE_DIR=${QTDIR:+${QTDIR}/include}
@@ -262,6 +265,9 @@ function to_key {
     libwebp)
       echo 28
     ;;
+    SVT-AV1)
+      echo 29
+    ;;
     *)
       echo UNKNOWN
     ;;
@@ -487,6 +493,9 @@ function set_globals {
     if test "$FFMPEG_SUPPORT_AOM" = 1 && test "$AOM_HEAD" = 1 -o "$AOM_REVISION" != ""; then
         SUBDIRS="aom $SUBDIRS"
     fi
+    if test "$FFMPEG_SUPPORT_SVTAV1" = 1 && test "$SVTAV1_HEAD" = 1 -o "$SVTAV1_REVISION" != ""; then
+        SUBDIRS="SVT-AV1 $SUBDIRS"
+    fi
     if test "$FFMPEG_SUPPORT_VMAF" = 1 && test "$VMAF_HEAD" = 1 -o "$VMAF_REVISION" != ""; then
         SUBDIRS="vmaf $SUBDIRS"
     fi
@@ -556,6 +565,7 @@ function set_globals {
   REPOLOCS[26]="https://github.com/opencv/opencv.git"
   REPOLOCS[27]="https://github.com/opencv/opencv_contrib.git"
   REPOLOCS[28]="https://github.com/webmproject/libwebp.git"
+  REPOLOCS[29]="https://gitlab.com/AOMediaCodec/SVT-AV1.git"
 
   # REPOTYPE Array holds the repo types. (Yes, this might be redundant, but easy for me)
   REPOTYPES[0]="git"
@@ -585,6 +595,7 @@ function set_globals {
   REPOTYPES[26]="git"
   REPOTYPES[27]="git"
   REPOTYPES[28]="git"
+  REPOTYPES[29]="git"
 
   # And, set up the revisions
   REVISIONS[0]=""
@@ -656,10 +667,6 @@ function set_globals {
   if test 0 = "$AOM_HEAD" -a "$AOM_REVISION" ; then
     REVISIONS[22]="$AOM_REVISION"
   fi
-  REVISIONS[22]=""
-  if test 0 = "$AOM_HEAD" -a "$AOM_REVISION" ; then
-    REVISIONS[22]="$AOM_REVISION"
-  fi
   REVISIONS[23]=""
   if test 0 = "$VMAF_HEAD" -a "$VMAF_REVISION" ; then
     REVISIONS[23]="$VMAF_REVISION"
@@ -679,7 +686,11 @@ function set_globals {
   fi
   REVISIONS[28]=""
   if test 0 = "$LIBWEBP_HEAD" -a "$LIBWEBP_REVISION" ; then
-  REVISIONS[28]="$LIBWEBP_REVISION"
+    REVISIONS[28]="$LIBWEBP_REVISION"
+  fi
+  REVISIONS[29]=""
+  if test 0 = "$SVTAV1_HEAD" -a "$SVTAV1_REVISION" ; then
+    REVISIONS[29]="$SVTAV1_REVISION"
   fi
 
   # Figure out the number of cores in the system. Used both by make and startup script
@@ -770,6 +781,9 @@ function set_globals {
   if test 1 = "$FFMPEG_SUPPORT_WEBP" ; then
     CONFIG[0]="${CONFIG[0]} --enable-libwebp"
   fi
+  if test 1 = "$FFMPEG_SUPPORT_SVTAV1" ; then
+    CONFIG[0]="${CONFIG[0]} --enable-libsvtav1"
+  fi
   if test 1 = "$FFMPEG_SUPPORT_VMAF" ; then
     CONFIG[0]="${CONFIG[0]} --enable-libvmaf"
   fi
@@ -778,7 +792,7 @@ function set_globals {
   fi
   # Add optional parameters
   CONFIG[0]="${CONFIG[0]} $FFMPEG_ADDITIONAL_OPTIONS"
-  CFLAGS_[0]="-I$FINAL_INSTALL_DIR/include $CFLAGS"
+  CFLAGS_[0]="-I$FINAL_INSTALL_DIR/include -Wno-incompatible-pointer-types $CFLAGS"
   LDFLAGS_[0]="-L$FINAL_INSTALL_DIR/lib $LDFLAGS"
   if test "$TARGET_OS" = "Darwin"; then
     CFLAGS_[0]="${CFLAGS_[0]} -I/opt/local/include"
@@ -793,7 +807,7 @@ function set_globals {
 
   #####
   # mlt
-  CONFIG[1]="cmake -GNinja -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -DCMAKE_PREFIX_PATH=$QTDIR -DMOD_QT=OFF -DMOD_QT6=ON -DMOD_GLAXNIMATE_QT6=ON -DMOD_GDK=OFF -DMOD_SDL1=OFF"
+  CONFIG[1]="cmake -GNinja -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -DCMAKE_PREFIX_PATH=$QTDIR -DMOD_QT=OFF -DMOD_QT6=ON -DMOD_GLAXNIMATE_QT6=ON -DMOD_GDK=OFF -DMOD_SDL1=OFF -DUSE_VST2=OFF"
   # Remember, if adding more of these, to update the post-configure check.
   [ "$ENABLE_OPENCV" = "1" ] && CONFIG[1]="${CONFIG[1]} -DMOD_OPENCV=ON"
   [ "$MLT_DISABLE_SOX" = "1" ] && CONFIG[1]="${CONFIG[1]} -DMOD_SOX=OFF"
@@ -1030,10 +1044,10 @@ function set_globals {
 
   #####
   # glaxnimate
-  CONFIG[24]="cmake -G Ninja -DCMAKE_PREFIX_PATH=$QTDIR -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG"
+  CONFIG[24]="cmake -G Ninja -DCMAKE_PREFIX_PATH='$FINAL_INSTALL_DIR;$QTDIR' -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG"
   if [ "$TARGET_OS" = "Darwin" ]; then
     CONFIG[24]="${CONFIG[24]} -DCMAKE_OSX_ARCHITECTURES='arm64;x86_64'"
-    CONFIG[24]="${CONFIG[24]} -DPython3_EXECUTABLE=/opt/local/Library/Frameworks/Python.framework/Versions/${PYTHON_VERSION_DARWIN}/bin/python${PYTHON_VERSION_DARWIN} -D PYTHON_EXECUTABLE=/opt/local/Library/Frameworks/Python.framework/Versions/${PYTHON_VERSION_DARWIN}/bin/python${PYTHON_VERSION_DARWIN}"
+    CONFIG[24]="${CONFIG[24]} -DPython3_EXECUTABLE=/opt/local/Library/Frameworks/Python.framework/Versions/${PYTHON_VERSION_DARWIN}/bin/python${PYTHON_VERSION_DARWIN}"
   fi
   CFLAGS_[24]="$ASAN_CFLAGS $CFLAGS"
   LDFLAGS_[24]="$ASAN_LDFLAGS $LDFLAGS"
@@ -1066,6 +1080,15 @@ function set_globals {
   LDFLAGS_[28]="$LDFLAGS"
   BUILD[28]="ninja -C build -j $MAKEJ"
   INSTALL[28]="ninja -C build install"
+
+  #####
+  # SVT-AV1
+  CONFIG[29]="cmake -B build -G Ninja -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG -D BUILD_SHARED_LIBS=ON -D BUILD_TESTING=OFF -D BUILD_APPS=OFF -D ENABLE_AVX512=ON"
+  [ "$TARGET_OS" = "Darwin" ] && CONFIG[29]="${CONFIG[29]} -D CMAKE_OSX_ARCHITECTURES='arm64;x86_64'"
+  CFLAGS_[29]=$CFLAGS
+  LDFLAGS_[29]=$LDFLAGS
+  BUILD[29]="ninja -C build -j $MAKEJ"
+  INSTALL[29]="ninja -C build install"
 }
 
 function build_ffmpeg_darwin {
@@ -1125,7 +1148,7 @@ function install_shotcut_linux {
   cmd install -p -c COPYING "$FINAL_INSTALL_DIR"
   cmd install -p -c "$QTDIR"/translations/qt_*.qm "$FINAL_INSTALL_DIR"/share/shotcut/translations
   cmd install -p -c "$QTDIR"/translations/qtbase_*.qm "$FINAL_INSTALL_DIR"/share/shotcut/translations
-  cmd install -p -c "$QTDIR"/lib/libQt6{Charts,Core,Core5Compat,DBus,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlModels,QmlWorkerScript,Quick,QuickControls2,QuickControls2Impl,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,Widgets,Xml,X11Extras,XcbQpa}.so.6 "$FINAL_INSTALL_DIR"/lib
+  cmd install -p -c "$QTDIR"/lib/libQt6{Charts,Core,Core5Compat,DBus,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlModels,QmlWorkerScript,Quick,QuickControls2*,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,WaylandClient,WaylandEglClientHwIntegration,Widgets,Xml,X11Extras,XcbQpa}.so.6 "$FINAL_INSTALL_DIR"/lib
   cmd install -p -c "$QTDIR"/lib/lib{icudata,icui18n,icuuc}.so* "$FINAL_INSTALL_DIR"/lib
   cmd install -d "$FINAL_INSTALL_DIR"/lib/qt6/sqldrivers
   cmd cp -a "$QTDIR"/plugins/{egldeviceintegrations,generic,iconengines,imageformats,multimedia,platforminputcontexts,platforms,platformthemes,tls,wayland-decoration-client,wayland-graphics-integration-client,wayland-shell-integration,xcbglintegrations} "$FINAL_INSTALL_DIR"/lib/qt6
@@ -1146,9 +1169,9 @@ function build_vmaf_darwin {
 function install_vmaf {
   if [ "$TARGET_OS" = "Darwin" ]; then
     cmd ninja install -C libvmaf/build-arm64
-    cmd rm "$FINAL_INSTALL_DIR"/lib/libvmaf.1.dylib
-    cmd lipo -create libvmaf/build-arm64/src/libvmaf.1.dylib libvmaf/build-x86_64/src/libvmaf.1.dylib -output "$FINAL_INSTALL_DIR"/lib/libvmaf.1.dylib
-    cmd install_name_tool -id "$FINAL_INSTALL_DIR"/lib/libvmaf.1.dylib "$FINAL_INSTALL_DIR"/lib/libvmaf.1.dylib
+    cmd rm "$FINAL_INSTALL_DIR"/lib/libvmaf.3.dylib
+    cmd lipo -create libvmaf/build-arm64/src/libvmaf.3.dylib libvmaf/build-x86_64/src/libvmaf.3.dylib -output "$FINAL_INSTALL_DIR"/lib/libvmaf.3.dylib
+    cmd install_name_tool -id "$FINAL_INSTALL_DIR"/lib/libvmaf.3.dylib "$FINAL_INSTALL_DIR"/lib/libvmaf.3.dylib
   else
     cmd ninja -C libvmaf/build install
   fi
@@ -1553,6 +1576,10 @@ function configure_compile_install_subproject {
       replace_rpath opencv_plot
       replace_rpath opencv_tracking
       replace_rpath opencv_video
+    elif [ "libspatialaudio" = "$1" ]; then
+      replace_rpath spatialaudio
+    elif [ "SVT-AV1" = "$1" ]; then
+    replace_rpath SvtAv1Enc
     elif [ "vid.stab" = "$1" ]; then
       cmd sed -e 's/-fopenmp//' -i .bak "$FINAL_INSTALL_DIR/lib/pkgconfig/vidstab.pc"
     fi
@@ -1940,7 +1967,7 @@ function deploy_mac
       dmg_name="$INSTALL_DIR/unsigned.dmg"
       cmd rm "$dmg_name" 2>/dev/null
       sync
-      cmd hdiutil create -fs HFS+ -srcfolder staging -volname Shotcut -format UDBZ -size 900m "$dmg_name"
+      cmd hdiutil create -fs HFS+ -srcfolder staging -volname Shotcut -format UDBZ -size 1500m "$dmg_name"
 
       if [ "$ACTION_CLEANUP" = "1" ]; then
         cmd rm -rf staging
@@ -2045,6 +2072,7 @@ export FREI0R_PATH="\$INSTALL_DIR/lib/frei0r-1"
 export LADSPA_PATH="\$INSTALL_DIR/lib/ladspa"
 export LIBVA_DRIVERS_PATH="\$INSTALL_DIR/lib/va"
 export PYTHONHOME="\$INSTALL_DIR"
+sed --help >/dev/null && export XDG_DATA_DIRS="\$(echo "\$XDG_DATA_DIRS" | sed "s|\$(dirname "\$INSTALL_DIR")||")"
 cd "\$INSTALL_DIR"
 export QT_PLUGIN_PATH="lib/qt6"
 export QML2_IMPORT_PATH="lib/qml"
