@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2019 Meltytech, LLC
+ * Copyright (c) 2012-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,24 +34,27 @@
 #include "settings.h"
 #include "database.h"
 #include "mainwindow.h"
+#include "proxymanager.h"
 
-static void deleteQImage(QImage* image)
+static void deleteQImage(QImage *image)
 {
     delete image;
 }
 
 class UpdateThumbnailTask : public QRunnable
 {
-    PlaylistModel* m_model;
+    PlaylistModel *m_model;
     Mlt::Producer m_producer;
     Mlt::Profile m_profile;
-    Mlt::Producer* m_tempProducer;
+    Mlt::Producer *m_tempProducer;
     int m_in;
     int m_out;
     int m_row;
+    bool m_force;
 
 public:
-    UpdateThumbnailTask(PlaylistModel* model, Mlt::Producer& producer, int in, int out, int row)
+    UpdateThumbnailTask(PlaylistModel *model, Mlt::Producer &producer, int in, int out, int row,
+                        bool force = false)
         : QRunnable()
         , m_model(model)
         , m_producer(producer)
@@ -60,6 +63,7 @@ public:
         , m_in(in)
         , m_out(out)
         , m_row(row)
+        , m_force(force)
     {}
 
     ~UpdateThumbnailTask()
@@ -67,7 +71,7 @@ public:
         delete m_tempProducer;
     }
 
-    Mlt::Producer* tempProducer()
+    Mlt::Producer *tempProducer()
     {
         if (!m_tempProducer) {
             QString service = m_producer.get("mlt_service");
@@ -75,8 +79,13 @@ public:
                 service = "avformat";
             else if (service.startsWith("xml"))
                 service = "xml-nogl";
-            m_tempProducer = new Mlt::Producer(m_profile, service.toUtf8().constData(), m_producer.get("resource"));
-            if (m_tempProducer->is_valid()) {
+            if (service == "count") {
+                m_tempProducer = new Mlt::Producer(m_profile, service.toUtf8().constData(), "loader-nogl");
+            } else if (!Settings.playerGPU() || (service != "xml-nogl" && service != "consumer")) {
+                m_tempProducer = new Mlt::Producer(m_profile, service.toUtf8().constData(),
+                                                   m_producer.get("resource"));
+            }
+            if (m_tempProducer && m_tempProducer->is_valid()) {
                 Mlt::Filter scaler(m_profile, "swscale");
                 Mlt::Filter padder(m_profile, "resize");
                 Mlt::Filter converter(m_profile, "avcolor_space");
@@ -90,7 +99,7 @@ public:
 
     QString cacheKey(int frameNumber)
     {
-        QString time = m_producer.frames_to_time(frameNumber, mlt_time_clock);
+        QString time = m_producer.frames_to_time(frameNumber, Settings.timeFormat());
         // Reduce the precision to centiseconds to increase chance for cache hit
         // without much loss of accuracy.
         time = time.left(time.size() - 1);
@@ -98,9 +107,9 @@ public:
         QString resource = m_producer.get(kShotcutHashProperty);
         if (resource.isEmpty()) {
             key = QString("%1 %2 %3")
-                    .arg(m_producer.get("mlt_service"))
-                    .arg(m_producer.get("resource"))
-                    .arg(time);
+                  .arg(m_producer.get("mlt_service"))
+                  .arg(m_producer.get("resource"))
+                  .arg(time);
             QCryptographicHash hash(QCryptographicHash::Sha1);
             hash.addData(key.toUtf8());
             key = hash.result().toHex();
@@ -121,7 +130,7 @@ public:
         int outPoint = qRound(m_out / MLT.profile().fps() * m_profile.fps());
 
         QImage image = DB.getThumbnail(cacheKey(inPoint));
-        if (image.isNull()) {
+        if (m_force || image.isNull()) {
             image = makeThumbnail(inPoint);
             m_producer.set(kThumbnailInProperty, new QImage(image), 0, (mlt_destructor) deleteQImage, NULL);
             DB.putThumbnail(cacheKey(inPoint), image);
@@ -132,7 +141,7 @@ public:
 
         if (setting == "tall" || setting == "wide") {
             image = DB.getThumbnail(cacheKey(outPoint));
-            if (image.isNull()) {
+            if (m_force || image.isNull()) {
                 image = makeThumbnail(outPoint);
                 m_producer.set(kThumbnailOutProperty, new QImage(image), 0, (mlt_destructor) deleteQImage, NULL);
                 DB.putThumbnail(cacheKey(outPoint), image);
@@ -147,7 +156,12 @@ public:
     {
         int height = PlaylistModel::THUMBNAIL_HEIGHT * 2;
         int width = PlaylistModel::THUMBNAIL_WIDTH * 2;
-        return MLT.image(*tempProducer(), frameNumber, width, height);
+        auto producer = tempProducer();
+        if (producer && producer->is_valid()) {
+            return MLT.image(*tempProducer(), frameNumber, width, height);
+        } else {
+            return QImage();
+        }
     }
 
 signals:
@@ -156,33 +170,35 @@ signals:
 
 PlaylistModel::PlaylistModel(QObject *parent)
     : QAbstractTableModel(parent)
-    , m_playlist(0)
+    , m_playlist(nullptr)
     , m_dropRow(-1)
     , m_mode(Invalid)
 {
     qRegisterMetaType<QVector<int> >("QVector<int>");
+    connect(this, &QAbstractItemModel::rowsAboutToBeRemoved, this,
+            &PlaylistModel::onRowsAboutToBeRemoved);
 }
 
 PlaylistModel::~PlaylistModel()
 {
     delete m_playlist;
-    m_playlist = 0;
+    m_playlist = nullptr;
 }
 
-int PlaylistModel::rowCount(const QModelIndex& /*parent*/) const
+int PlaylistModel::rowCount(const QModelIndex & /*parent*/) const
 {
-    return m_playlist? m_playlist->count() : 0;
+    return m_playlist ? m_playlist->count() : 0;
 }
 
-int PlaylistModel::columnCount(const QModelIndex& /*parent*/) const
+int PlaylistModel::columnCount(const QModelIndex & /*parent*/) const
 {
     switch (m_mode) {
-        case Detailed:
-            return COLUMN_COUNT;
-        case Tiled:
-        case Icons:
-        case Invalid:
-            return 1;
+    case Detailed:
+        return COLUMN_COUNT;
+    case Tiled:
+    case Icons:
+    case Invalid:
+        return 1;
     }
     return 0;
 }
@@ -196,91 +212,101 @@ QVariant PlaylistModel::data(const QModelIndex &index, int role) const
 
     if (role < Qt::UserRole) {
         if (role == Qt::DisplayRole) {
-            if (m_mode == Detailed)
+            if (m_mode == Detailed || index.column() > 0)
                 field = FIELD_INDEX + index.column();
             else
                 field = FIELD_RESOURCE;
         } else if (role == Qt::ToolTipRole) {
             field = FIELD_RESOURCE;
-        }
-        else if (role == Qt::DecorationRole) {
+        } else if (role == Qt::DecorationRole) {
             if (m_mode == Detailed && index.column() != COLUMN_THUMBNAIL)
                 return QVariant();
             field = FIELD_THUMBNAIL;
-        }
-        else
+        } else
             return QVariant();
     }
 
     QScopedPointer<Mlt::ClipInfo> info(m_playlist->clip_info(index.row()));
-    switch (field) {
-    case FIELD_INDEX:
-        return QString::number(index.row() + 1);
-    case FIELD_RESOURCE:
-        {
-        QString result;
-        if (role == Qt::DisplayRole) {
-            // Prefer caption for display
-            if (info->producer && info->producer->is_valid())
-                result = info->producer->get(kShotcutCaptionProperty);
-            if (result.isNull())
-                result = Util::baseName(QString::fromUtf8(info->resource));
-            if (result == "<producer>" && info->producer && info->producer->is_valid())
-                result = QString::fromUtf8(info->producer->get("mlt_service"));
-        } else {
-            // Prefer detail or full path for tooltip
-            if (info->producer && info->producer->is_valid())
-                result = info->producer->get(kShotcutDetailProperty);
-            if (result.isNull()) {
-                if (!::qstrcmp(info->producer->get("mlt_service"), "timewarp"))
-                    result = QString::fromUtf8(info->producer->get("warp_resource"));
-                else
-                    result = QString::fromUtf8(info->resource);
-                if (!result.isEmpty() && QFileInfo(result).isRelative()) {
-                    QString basePath = QFileInfo(MAIN.fileName()).canonicalPath();
-                    result = QFileInfo(basePath, result).filePath();
+    if (info)
+        switch (field) {
+        case FIELD_INDEX:
+            return QString::number(index.row() + 1);
+        case FIELD_RESOURCE: {
+            QString result;
+            if (role == Qt::DisplayRole) {
+                // Prefer caption for display
+                if (info->producer && info->producer->is_valid()) {
+                    result = info->producer->get(kShotcutCaptionProperty);
+                    if (result.isEmpty()) {
+                        result = Util::baseName(ProxyManager::resource(*info->producer));
+                        if (!::qstrcmp(info->producer->get("mlt_service"), "timewarp")) {
+                            double speed = ::qAbs(info->producer->get_double("warp_speed"));
+                            result = QString("%1 (%2x)").arg(result).arg(speed);
+                        }
+                    }
+                    if (result == "<producer>") {
+                        result = QString::fromUtf8(info->producer->get("mlt_service"));
+                    }
+                    if (info->producer->get_int(kIsProxyProperty)) {
+                        result.append("\n" + tr("(PROXY)"));
+                    }
+                }
+            } else {
+                // Prefer detail or full path for tooltip
+                if (info->producer && info->producer->is_valid()) {
+                    result = info->producer->get(kShotcutDetailProperty);
+                    if (result.isEmpty()) {
+                        result = ProxyManager::resource(*info->producer);
+                        if (!result.isEmpty() && QFileInfo(result).isRelative()) {
+                            QString basePath = QFileInfo(MAIN.fileName()).canonicalPath();
+                            result = QFileInfo(basePath, result).filePath();
+                        }
+                        result = QDir::toNativeSeparators(result);
+                    }
+                    if ((result.isEmpty() || Util::baseName(result) == "<producer>")) {
+                        result = info->producer->get(kShotcutCaptionProperty);
+                    }
+                    if (result.isEmpty()) {
+                        result = QString::fromUtf8(info->producer->get("mlt_service"));
+                    }
                 }
-                result = QDir::toNativeSeparators(result);
             }
-            if ((result.isNull() || Util::baseName(result) == "<producer>") && info->producer && info->producer->is_valid())
-                result = info->producer->get(kShotcutCaptionProperty);
-            if (result.isNull() && info->producer && info->producer->is_valid())
-                result = QString::fromUtf8(info->producer->get("mlt_service"));
+            if (!info->producer->get(kShotcutHashProperty)) {
+                Util::getHash(*info->producer);
+            }
+            return result;
         }
-        if (!info->producer->get(kShotcutHashProperty))
-            MAIN.getHash(*info->producer);
-        return result;
-    }
-    case FIELD_IN:
-        if (info->producer && info->producer->is_valid()) {
-            return info->producer->frames_to_time(info->frame_in);
-        } else
-            return "";
-    case FIELD_DURATION:
-        if (info->producer && info->producer->is_valid()) {
-            return info->producer->frames_to_time(info->frame_count);
-        } else
-            return "";
-    case FIELD_START:
-        if (info->producer && info->producer->is_valid()) {
-            return info->producer->frames_to_time(info->start);
-        }
-        else
-            return "";
-    case FIELD_DATE:
-        if (info->producer && info->producer->is_valid()) {
-            int64_t ms = info->producer->get_creation_time();
-            if (!ms) {
+        case FIELD_IN:
+            if (info->producer && info->producer->is_valid()) {
+                return QString::fromLatin1(info->producer->frames_to_time(info->frame_in, Settings.timeFormat()));
+            } else {
                 return "";
             }
-            else {
-               return QDateTime::fromMSecsSinceEpoch(ms).toString("yyyy-MM-dd HH:mm:ss");
+        case FIELD_DURATION:
+            if (info->producer && info->producer->is_valid()) {
+                return QString::fromLatin1(info->producer->frames_to_time(info->frame_count,
+                                                                          Settings.timeFormat()));
+            } else {
+                return "";
             }
-        }
-        else
-            return "";
-    case FIELD_THUMBNAIL:
-        {
+        case FIELD_START:
+            if (info->producer && info->producer->is_valid()) {
+                return QString::fromLatin1(info->producer->frames_to_time(info->start, Settings.timeFormat()));
+            } else {
+                return "";
+            }
+        case FIELD_DATE:
+            if (info->producer && info->producer->is_valid()) {
+                int64_t ms = info->producer->get_creation_time();
+                if (!ms) {
+                    return "";
+                } else {
+                    return QDateTime::fromMSecsSinceEpoch(ms).toString("yyyy-MM-dd HH:mm:ss");
+                }
+            } else {
+                return "";
+            }
+        case FIELD_THUMBNAIL: {
             QString setting = Settings.playlistThumbnails();
             if (setting == "hidden")
                 return QImage();
@@ -304,7 +330,7 @@ QVariant PlaylistModel::data(const QModelIndex &index, int role) const
                 image.fill(QApplication::palette().base().color().rgb());
 
                 // draw the in thumbnail
-                QImage* thumb = (QImage*) parent.get_data(kThumbnailInProperty);
+                QImage *thumb = (QImage *) parent.get_data(kThumbnailInProperty);
                 QRect rect = thumb->rect();
                 if (setting != "large") {
                     rect.setWidth(width);
@@ -314,26 +340,33 @@ QVariant PlaylistModel::data(const QModelIndex &index, int role) const
 
                 if ((setting == "wide" || setting == "tall") && parent.get_data(kThumbnailOutProperty)) {
                     // draw the out thumbnail
-                    thumb = (QImage*) parent.get_data(kThumbnailOutProperty);
+                    thumb = (QImage *) parent.get_data(kThumbnailOutProperty);
                     if (setting == "wide") {
                         rect.setWidth(width * 2);
                         rect.setLeft(width);
-                    }
-                    else if (setting == "tall") {
+                    } else if (setting == "tall") {
                         rect.setHeight(THUMBNAIL_HEIGHT * 2);
                         rect.setTop(THUMBNAIL_HEIGHT);
                     }
                     painter.drawImage(rect, *thumb);
                 }
+                if (parent.is_valid() && parent.get_int(kPlaylistIndexProperty) == index.row() + 1) {
+                    QPen pen(Qt::red);
+                    pen.setWidthF(1.5 * MAIN.devicePixelRatioF());
+                    painter.setPen(pen);
+                    rect.setX(0);
+                    rect.setY(0);
+                    rect.setWidth(rect.width() - 1);
+                    rect.setHeight(rect.height() - 1);
+                    painter.drawRect(rect);
+                }
                 painter.end();
-            }
-            else {
+            } else {
                 image.fill(QApplication::palette().base().color().rgb());
             }
             return image;
         }
-        break;
-    }
+        }
     return QVariant();
 }
 
@@ -354,8 +387,7 @@ void PlaylistModel::setViewMode(ViewMode mode)
 
 QVariant PlaylistModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
-    if (role == Qt::DisplayRole && orientation == Qt::Horizontal)
-    {
+    if (role == Qt::DisplayRole && orientation == Qt::Horizontal) {
         switch (section) {
         case COLUMN_INDEX:
             return tr("#");
@@ -383,7 +415,7 @@ Qt::DropActions PlaylistModel::supportedDropActions() const
     return Qt::CopyAction | Qt::MoveAction | Qt::LinkAction;
 }
 
-bool PlaylistModel::insertRows(int row, int count, const QModelIndex& parent)
+bool PlaylistModel::insertRows(int row, int count, const QModelIndex &parent)
 {
     Q_UNUSED(count)
     Q_UNUSED(parent)
@@ -393,20 +425,38 @@ bool PlaylistModel::insertRows(int row, int count, const QModelIndex& parent)
     return true;
 }
 
-bool PlaylistModel::removeRows(int row, int count, const QModelIndex& parent)
+bool PlaylistModel::removeRows(int row, int count, const QModelIndex &parent)
 {
     Q_UNUSED(count)
     Q_UNUSED(parent)
-    if (!m_playlist || row == m_dropRow || m_dropRow == -1 ) return false;
-    if (row < m_dropRow)
-        emit moveClip(row, m_dropRow - 1);
-    else
-        emit moveClip(row, m_dropRow);
+    if (!m_playlist || m_dropRow == -1 ) return false;
+    if (row < m_dropRow) {
+        if (!m_rowsRemoved.contains(row)) {
+            int adjustment = 0;
+            foreach (int i, m_rowsRemoved) {
+                if (row > i)
+                    --adjustment;
+            }
+            m_rowsRemoved << row;
+            emit moveClip(row + adjustment, m_dropRow - 1);
+        }
+    } else {
+        if (!m_rowsRemoved.contains(row)) {
+            foreach (int i, m_rowsRemoved) {
+                if (row >= i)
+                    ++row;
+            }
+        }
+        m_rowsRemoved << m_dropRow;
+        if (row != m_dropRow)
+            emit moveClip(row, m_dropRow++);
+    }
     m_dropRow = -1;
     return true;
 }
 
-bool PlaylistModel::moveRows(const QModelIndex &, int sourceRow, int count, const QModelIndex &, int destinationChild)
+bool PlaylistModel::moveRows(const QModelIndex &, int sourceRow, int count, const QModelIndex &,
+                             int destinationChild)
 {
     Q_ASSERT(count == 1);
     move(sourceRow, destinationChild);
@@ -425,7 +475,7 @@ void PlaylistModel::sort(int column, Qt::SortOrder order)
     QVector<QPair<QString, int>> indexMap(count);
     for (index = 0; index < count; index++) {
         QModelIndex modelIndex = createIndex(index, column);
-        QString key = data(modelIndex, Qt::DisplayRole).toString();
+        QString key = data(modelIndex, Qt::DisplayRole).toString().toLower();
         indexMap[index] = qMakePair(key, index);
     }
     // Sort the list.
@@ -462,27 +512,33 @@ QStringList PlaylistModel::mimeTypes() const
 QMimeData *PlaylistModel::mimeData(const QModelIndexList &indexes) const
 {
     QMimeData *mimeData = new QMimeData;
-    Mlt::ClipInfo* info = m_playlist->clip_info(indexes.first().row());
-    if (info) {
-        Mlt::Producer* producer = info->producer;
-        int in = producer->get_in();
-        int out = producer->get_out();
-        producer->set_in_and_out(info->frame_in, info->frame_out);
-        mimeData->setData(Mlt::XmlMimeType, MLT.XML(producer).toUtf8());
-        mimeData->setText(QString::number(info->frame_count));
-        producer->set_in_and_out(in, out);
-        delete info;
+    int count = 0;
+    foreach (auto index, indexes) {
+        if (index.column()) continue;
+        count += m_playlist->clip_length(index.row());
     }
+    Mlt::Playlist playlist(MLT.profile());
+    foreach (auto index, indexes) {
+        if (index.column()) continue;
+        QScopedPointer<Mlt::ClipInfo> info(m_playlist->clip_info(index.row()));
+        if (info && info->producer) {
+            playlist.append(*info->producer, info->frame_in, info->frame_out);
+        }
+    }
+    mimeData->setData(Mlt::XmlMimeType, MLT.XML(&playlist).toUtf8());
+    mimeData->setText(QString::number(count));
     return mimeData;
 }
 
-bool PlaylistModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent)
+bool PlaylistModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column,
+                                 const QModelIndex &parent)
 {
     Q_UNUSED(column)
     Q_UNUSED(parent)
     // Internal reorder
-    if (action == Qt::MoveAction) {
+    if (action == Qt::MoveAction && !data->hasUrls()) {
         m_dropRow = row;
+        m_rowsRemoved.clear();
         return true;
     }
     // Dragged from player or file manager
@@ -521,7 +577,7 @@ Qt::ItemFlags PlaylistModel::flags(const QModelIndex &index) const
         return Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled | defaults;
 }
 
-QModelIndex PlaylistModel::incrementIndex(const QModelIndex& index) const
+QModelIndex PlaylistModel::incrementIndex(const QModelIndex &index) const
 {
     if (index.row() + 1 < rowCount())
         return createIndex(index.row() + 1, index.column());
@@ -529,10 +585,10 @@ QModelIndex PlaylistModel::incrementIndex(const QModelIndex& index) const
         return QModelIndex();
 }
 
-QModelIndex PlaylistModel::decrementIndex(const QModelIndex& index) const
+QModelIndex PlaylistModel::decrementIndex(const QModelIndex &index) const
 {
     if (index.row() > 0)
-        return createIndex(index.row() -1, index.column());
+        return createIndex(index.row() - 1, index.column());
     else
         return QModelIndex();
 }
@@ -572,7 +628,7 @@ void PlaylistModel::load()
     m_playlist = new Mlt::Playlist(*MLT.producer());
     if (!m_playlist->is_valid()) {
         delete m_playlist;
-        m_playlist = 0;
+        m_playlist = nullptr;
         return;
     }
     if (m_playlist->count() > 0) {
@@ -584,7 +640,7 @@ void PlaylistModel::load()
     emit loaded();
 }
 
-void PlaylistModel::append(Mlt::Producer& producer, bool emitModified)
+void PlaylistModel::append(Mlt::Producer &producer, bool emitModified)
 {
     createIfNeeded();
     int count = m_playlist->count();
@@ -600,7 +656,7 @@ void PlaylistModel::append(Mlt::Producer& producer, bool emitModified)
         emit modified();
 }
 
-void PlaylistModel::insert(Mlt::Producer& producer, int row)
+void PlaylistModel::insert(Mlt::Producer &producer, int row)
 {
     createIfNeeded();
     int in = producer.get_in();
@@ -626,7 +682,7 @@ void PlaylistModel::remove(int row)
         emit modified();
 }
 
-void PlaylistModel::update(int row, Mlt::Producer& producer)
+void PlaylistModel::update(int row, Mlt::Producer &producer, bool copyFilters)
 {
     if (!m_playlist) return;
     int in = producer.get_in();
@@ -634,12 +690,28 @@ void PlaylistModel::update(int row, Mlt::Producer& producer)
     producer.set_in_and_out(0, producer.get_length() - 1);
     QThreadPool::globalInstance()->start(
         new UpdateThumbnailTask(this, producer, in, out, row), 1);
+    if (copyFilters) {
+        Mlt::Producer oldClip(m_playlist->get_clip(row));
+        Q_ASSERT(oldClip.is_valid());
+        Mlt::Controller::copyFilters(oldClip.parent(), producer);
+        Mlt::Controller::adjustFilters(producer);
+    }
     m_playlist->remove(row);
     m_playlist->insert(producer, row, in, out);
     emit dataChanged(createIndex(row, 0), createIndex(row, columnCount()));
     emit modified();
 }
 
+void PlaylistModel::updateThumbnails(int row)
+{
+    if (!m_playlist) return;
+    QScopedPointer<Mlt::ClipInfo> info(m_playlist->clip_info(row));
+    if (!info || !info->producer->is_valid()) return;
+    QThreadPool::globalInstance()->start(
+        new UpdateThumbnailTask(this, *info->producer, info->frame_in, info->frame_out, row,
+                                true /* force */), 1);
+}
+
 void PlaylistModel::appendBlank(int frames)
 {
     createIfNeeded();
@@ -664,7 +736,7 @@ void PlaylistModel::close()
     if (!m_playlist) return;
     clear();
     delete m_playlist;
-    m_playlist = 0;
+    m_playlist = nullptr;
     emit closed();
 }
 
@@ -677,6 +749,15 @@ void PlaylistModel::move(int from, int to)
     emit modified();
 }
 
+void PlaylistModel::onRowsAboutToBeRemoved(const QModelIndex &parent, int first, int last)
+{
+    if (m_playlist) {
+        for (int i = first; i <= last; ++i) {
+            emit removing(m_playlist->get_clip(i));
+        }
+    }
+}
+
 void PlaylistModel::createIfNeeded()
 {
     if (!m_playlist) {
@@ -696,7 +777,7 @@ void PlaylistModel::refreshThumbnails()
 {
     if (m_playlist && m_playlist->is_valid()) {
         for (int i = 0; i < m_playlist->count(); i++) {
-            Mlt::ClipInfo* info = m_playlist->clip_info(i);
+            Mlt::ClipInfo *info = m_playlist->clip_info(i);
             if (info && info->producer && info->producer->is_valid()) {
                 QThreadPool::globalInstance()->start(
                     new UpdateThumbnailTask(this, *info->producer, info->frame_in, info->frame_out, i), 1);
@@ -706,7 +787,7 @@ void PlaylistModel::refreshThumbnails()
     }
 }
 
-void PlaylistModel::setPlaylist(Mlt::Playlist& playlist)
+void PlaylistModel::setPlaylist(Mlt::Playlist &playlist)
 {
     if (playlist.is_valid()) {
         if (m_playlist) {
