@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2020 Meltytech, LLC
+ * Copyright (c) 2013-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,18 +16,23 @@
  */
 
 #include "settings.h"
+#include <QApplication>
 #include <QColor>
 #include <QLocale>
 #include <QStandardPaths>
 #include <QFile>
 #include <QDir>
+#include <QMediaDevices>
+#include <QAudioDevice>
 #include <Logger.h>
 
 static const QString APP_DATA_DIR_KEY("appdatadir");
 static const QString SHOTCUT_INI_FILENAME("/shotcut.ini");
+static const QString RECENT_INI_FILENAME("recent.ini");
 static QScopedPointer<ShotcutSettings> instance;
 static QString appDataForSession;
 static const int kMaximumTrackHeight = 125;
+static const QString kRecentKey("recent");
 
 ShotcutSettings &ShotcutSettings::singleton()
 {
@@ -35,7 +40,7 @@ ShotcutSettings &ShotcutSettings::singleton()
         if (appDataForSession.isEmpty()) {
             instance.reset(new ShotcutSettings);
             if (instance->settings.value(APP_DATA_DIR_KEY).isValid()
-                && QFile::exists(instance->settings.value(APP_DATA_DIR_KEY).toString() + SHOTCUT_INI_FILENAME) )
+                    && QFile::exists(instance->settings.value(APP_DATA_DIR_KEY).toString() + SHOTCUT_INI_FILENAME) )
                 instance.reset(new ShotcutSettings(instance->settings.value(APP_DATA_DIR_KEY).toString()));
         } else {
             instance.reset(new ShotcutSettings(appDataForSession));
@@ -44,25 +49,73 @@ ShotcutSettings &ShotcutSettings::singleton()
     return *instance;
 }
 
-ShotcutSettings::ShotcutSettings(const QString& appDataLocation)
+ShotcutSettings::ShotcutSettings()
+    : QObject()
+    , m_recent(QDir(appDataLocation()).filePath(RECENT_INI_FILENAME), QSettings::IniFormat)
+{
+    migrateLayout();
+    migrateRecent();
+}
+
+ShotcutSettings::ShotcutSettings(const QString &appDataLocation)
     : QObject()
     , settings(appDataLocation + SHOTCUT_INI_FILENAME, QSettings::IniFormat)
     , m_appDataLocation(appDataLocation)
+    , m_recent(QDir(appDataLocation).filePath(RECENT_INI_FILENAME), QSettings::IniFormat)
 {
+    migrateLayout();
+    migrateRecent();
+}
+
+void ShotcutSettings::migrateRecent()
+{
+    // Migrate recent to separate INI file
+    auto oldRecents = settings.value(kRecentKey).toStringList();
+    if (recent().isEmpty() && !oldRecents.isEmpty()) {
+        auto newRecents = recent();
+        for (const auto &a : oldRecents) {
+            if (a.size() < ShotcutSettings::MaxPath && !newRecents.contains(a)) {
+                while (newRecents.size() > 100) {
+                    newRecents.removeFirst();
+                }
+                newRecents.append(a);
+            }
+        }
+        setRecent(newRecents);
+        m_recent.sync();
+//        settings.remove("recent");
+        settings.sync();
+    }
+}
+
+void ShotcutSettings::migrateLayout()
+{
+    // Migrate old startup layout to a custom layout and start fresh
+    if (!settings.contains("geometry2")) {
+        auto geometry = settings.value("geometry").toByteArray();
+        auto windowState = settings.value("windowState").toByteArray();
+        setLayout(tr("Old (before v23) Layout"), geometry, windowState);
+        setLayoutMode(2);
+        settings.sync();
+    }
 }
 
 void ShotcutSettings::log()
 {
-    LOG_DEBUG() << "language" << language();
-    LOG_DEBUG() << "deinterlacer" << playerDeinterlacer();
-    LOG_DEBUG() << "external monitor" << playerExternal();
-    LOG_DEBUG() << "GPU processing" << playerGPU();
-    LOG_DEBUG() << "interpolation" << playerInterpolation();
-    LOG_DEBUG() << "video mode" << playerProfile();
-    LOG_DEBUG() << "realtime" << playerRealtime();
-    LOG_DEBUG() << "audio channels" << playerAudioChannels();
-#ifdef Q_OS_WIN
-    LOG_DEBUG() << "display method" << drawMethod();
+    LOG_INFO() << "language" << language();
+    LOG_INFO() << "deinterlacer" << playerDeinterlacer();
+    LOG_INFO() << "external monitor" << playerExternal();
+    LOG_INFO() << "GPU processing" << playerGPU();
+    LOG_INFO() << "interpolation" << playerInterpolation();
+    LOG_INFO() << "video mode" << playerProfile();
+    LOG_INFO() << "realtime" << playerRealtime();
+    LOG_INFO() << "audio channels" << playerAudioChannels();
+#if defined(Q_OS_WIN) || defined(Q_OS_LINUX)
+    if (::qEnvironmentVariableIsSet("SDL_AUDIODRIVER")) {
+        LOG_INFO() << "audio driver" <<::qgetenv("SDL_AUDIODRIVER");
+    } else {
+        LOG_INFO() << "audio driver" << playerAudioDriver();
+    }
 #endif
 }
 
@@ -74,7 +127,7 @@ QString ShotcutSettings::language() const
     return language;
 }
 
-void ShotcutSettings::setLanguage(const QString& s)
+void ShotcutSettings::setLanguage(const QString &s)
 {
     settings.setValue("language", s);
 }
@@ -91,10 +144,11 @@ void ShotcutSettings::setImageDuration(double d)
 
 QString ShotcutSettings::openPath() const
 {
-    return settings.value("openPath", QStandardPaths::standardLocations(QStandardPaths::MoviesLocation)).toString();
+    return settings.value("openPath",
+                          QStandardPaths::standardLocations(QStandardPaths::MoviesLocation)).toString();
 }
 
-void ShotcutSettings::setOpenPath(const QString& s)
+void ShotcutSettings::setOpenPath(const QString &s)
 {
     settings.setValue("openPath", s);
     emit savePathChanged();
@@ -102,10 +156,11 @@ void ShotcutSettings::setOpenPath(const QString& s)
 
 QString ShotcutSettings::savePath() const
 {
-    return settings.value("savePath", QStandardPaths::standardLocations(QStandardPaths::DocumentsLocation)).toString();
+    return settings.value("savePath",
+                          QStandardPaths::standardLocations(QStandardPaths::DocumentsLocation)).toString();
 }
 
-void ShotcutSettings::setSavePath(const QString& s)
+void ShotcutSettings::setSavePath(const QString &s)
 {
     settings.setValue("savePath", s);
     emit savePathChanged();
@@ -113,15 +168,15 @@ void ShotcutSettings::setSavePath(const QString& s)
 
 QStringList ShotcutSettings::recent() const
 {
-    return settings.value("recent").toStringList();
+    return m_recent.value(kRecentKey).toStringList();
 }
 
-void ShotcutSettings::setRecent(const QStringList& ls)
+void ShotcutSettings::setRecent(const QStringList &ls)
 {
     if (ls.isEmpty())
-        settings.remove("recent");
+        m_recent.remove(kRecentKey);
     else if (!clearRecent())
-        settings.setValue("recent", ls);
+        m_recent.setValue(kRecentKey, ls);
 }
 
 QString ShotcutSettings::theme() const
@@ -129,11 +184,25 @@ QString ShotcutSettings::theme() const
     return settings.value("theme", "dark").toString();
 }
 
-void ShotcutSettings::setTheme(const QString& s)
+void ShotcutSettings::setTheme(const QString &s)
 {
     settings.setValue("theme", s);
 }
 
+QThread::Priority ShotcutSettings::jobPriority() const
+{
+    const auto priority = settings.value("jobPriority", "low").toString();
+    if (priority == "low") {
+        return QThread::LowPriority;
+    }
+    return QThread::NormalPriority;
+}
+
+void ShotcutSettings::setJobPriority(const QString &s)
+{
+    settings.setValue("jobPriority", s);
+}
+
 bool ShotcutSettings::showTitleBars() const
 {
     return settings.value("titleBars", true).toBool();
@@ -177,12 +246,12 @@ void ShotcutSettings::setSmallIcons(bool b)
 
 QByteArray ShotcutSettings::windowGeometry() const
 {
-    return settings.value("geometry").toByteArray();
+    return settings.value("geometry2").toByteArray();
 }
 
-void ShotcutSettings::setWindowGeometry(const QByteArray& a)
+void ShotcutSettings::setWindowGeometry(const QByteArray &a)
 {
-    settings.setValue("geometry", a);
+    settings.setValue("geometry2", a);
 }
 
 QByteArray ShotcutSettings::windowGeometryDefault() const
@@ -190,19 +259,19 @@ QByteArray ShotcutSettings::windowGeometryDefault() const
     return settings.value("geometryDefault").toByteArray();
 }
 
-void ShotcutSettings::setWindowGeometryDefault(const QByteArray& a)
+void ShotcutSettings::setWindowGeometryDefault(const QByteArray &a)
 {
     settings.setValue("geometryDefault", a);
 }
 
 QByteArray ShotcutSettings::windowState() const
 {
-    return settings.value("windowState").toByteArray();
+    return settings.value("windowState2").toByteArray();
 }
 
-void ShotcutSettings::setWindowState(const QByteArray& a)
+void ShotcutSettings::setWindowState(const QByteArray &a)
 {
-    settings.setValue("windowState", a);
+    settings.setValue("windowState2", a);
 }
 
 QByteArray ShotcutSettings::windowStateDefault() const
@@ -210,7 +279,7 @@ QByteArray ShotcutSettings::windowStateDefault() const
     return settings.value("windowStateDefault").toByteArray();
 }
 
-void ShotcutSettings::setWindowStateDefault(const QByteArray& a)
+void ShotcutSettings::setWindowStateDefault(const QByteArray &a)
 {
     settings.setValue("windowStateDefault", a);
 }
@@ -220,7 +289,7 @@ QString ShotcutSettings::viewMode() const
     return settings.value("playlist/viewMode").toString();
 }
 
-void ShotcutSettings::setViewMode(const QString& viewMode)
+void ShotcutSettings::setViewMode(const QString &viewMode)
 {
     settings.setValue("playlist/viewMode", viewMode);
     emit viewModeChanged();
@@ -231,17 +300,18 @@ QString ShotcutSettings::exportFrameSuffix() const
     return settings.value("exportFrameSuffix", ".png").toString();
 }
 
-void ShotcutSettings::setExportFrameSuffix(const QString& exportFrameSuffix)
+void ShotcutSettings::setExportFrameSuffix(const QString &exportFrameSuffix)
 {
     settings.setValue("exportFrameSuffix", exportFrameSuffix);
 }
 
 QString ShotcutSettings::encodePath() const
 {
-    return settings.value("encode/path", QStandardPaths::standardLocations(QStandardPaths::MoviesLocation)).toString();
+    return settings.value("encode/path",
+                          QStandardPaths::standardLocations(QStandardPaths::MoviesLocation)).toString();
 }
 
-void ShotcutSettings::setEncodePath(const QString& s)
+void ShotcutSettings::setEncodePath(const QString &s)
 {
     settings.setValue("encode/path", s);
 }
@@ -271,7 +341,7 @@ QStringList ShotcutSettings::encodeHardware() const
     return settings.value("encode/hardware").toStringList();
 }
 
-void ShotcutSettings::setEncodeHardware(const QStringList& ls)
+void ShotcutSettings::setEncodeHardware(const QStringList &ls)
 {
     if (ls.isEmpty())
         settings.remove("encode/hardware");
@@ -339,7 +409,7 @@ QString ShotcutSettings::playerDeinterlacer() const
     return result;
 }
 
-void ShotcutSettings::setPlayerDeinterlacer(const QString& s)
+void ShotcutSettings::setPlayerDeinterlacer(const QString &s)
 {
     settings.setValue("player/deinterlacer", s);
 }
@@ -348,27 +418,17 @@ QString ShotcutSettings::playerExternal() const
 {
     auto result = settings.value("player/external", "").toString();
     // "sdi" is no longer supported DVEO VidPort
-    return result == "sdi"? "" : result;
+    return result == "sdi" ? "" : result;
 }
 
-void ShotcutSettings::setPlayerExternal(const QString& s)
+void ShotcutSettings::setPlayerExternal(const QString &s)
 {
     settings.setValue("player/external", s);
 }
 
-QString ShotcutSettings::playerGamma() const
-{
-    return settings.value("player/gamma", "bt709").toString();
-}
-
-void ShotcutSettings::setPlayerGamma(const QString& s)
-{
-    settings.setValue("player/gamma", s);
-}
-
 void ShotcutSettings::setPlayerGPU(bool b)
 {
-    settings.setValue("player/gpu", b);
+    settings.setValue("player/gpu2", b);
     emit playerGpuChanged();
 }
 
@@ -382,19 +442,19 @@ QString ShotcutSettings::playerInterpolation() const
     return settings.value("player/interpolation", "bilinear").toString();
 }
 
-void ShotcutSettings::setPlayerInterpolation(const QString& s)
+void ShotcutSettings::setPlayerInterpolation(const QString &s)
 {
     settings.setValue("player/interpolation", s);
 }
 
 bool ShotcutSettings::playerGPU() const
 {
-    return settings.value("player/gpu", false).toBool();
+    return settings.value("player/gpu2", false).toBool();
 }
 
 bool ShotcutSettings::playerWarnGPU() const
 {
-    return settings.value("player/warnGPU", false).toBool();
+    return false; //settings.value("player/warnGPU", false).toBool();
 }
 
 void ShotcutSettings::setPlayerJACK(bool b)
@@ -427,7 +487,7 @@ QString ShotcutSettings::playerProfile() const
     return settings.value("player/profile", "").toString();
 }
 
-void ShotcutSettings::setPlayerProfile(const QString& s)
+void ShotcutSettings::setPlayerProfile(const QString &s)
 {
     settings.setValue("player/profile", s);
 }
@@ -502,12 +562,41 @@ void ShotcutSettings::setPlayerVideoDelayMs(int i)
     settings.setValue("player/videoDelayMs", i);
 }
 
+double ShotcutSettings::playerJumpSeconds() const
+{
+    return settings.value("player/jumpSeconds", 60.0).toDouble();
+}
+
+void ShotcutSettings::setPlayerJumpSeconds(double i)
+{
+    settings.setValue("player/jumpSeconds", i);
+}
+
+QString ShotcutSettings::playerAudioDriver() const
+{
+#if defined(Q_OS_WIN)
+    auto s = playerAudioChannels() > 2 ? "directsound" : "winmm";
+#else
+    auto s = "pulseaudio";
+#endif
+    if (::qEnvironmentVariableIsSet("SDL_AUDIODRIVER")) {
+        return ::qgetenv("SDL_AUDIODRIVER");
+    } else {
+        return settings.value("player/audioDriver", s).toString();
+    }
+}
+
+void ShotcutSettings::setPlayerAudioDriver(const QString &s)
+{
+    settings.setValue("player/audioDriver", s);
+}
+
 QString ShotcutSettings::playlistThumbnails() const
 {
     return settings.value("playlist/thumbnails", "small").toString();
 }
 
-void ShotcutSettings::setPlaylistThumbnails(const QString& s)
+void ShotcutSettings::setPlaylistThumbnails(const QString &s)
 {
     settings.setValue("playlist/thumbnails", s);
     emit playlistThumbnailsChanged();
@@ -523,6 +612,16 @@ void ShotcutSettings::setPlaylistAutoplay(bool b)
     settings.setValue("playlist/autoplay", b);
 }
 
+bool ShotcutSettings::playlistShowColumn(const QString &column)
+{
+    return settings.value("playlist/columns/" + column, true).toBool();
+}
+
+void ShotcutSettings::setPlaylistShowColumn(const QString &column, bool b)
+{
+    settings.setValue("playlist/columns/" + column, b);
+}
+
 bool ShotcutSettings::timelineDragScrub() const
 {
     return settings.value("timeline/dragScrub", false).toBool();
@@ -600,17 +699,6 @@ void ShotcutSettings::setTimelineSnap(bool b)
     emit timelineSnapChanged();
 }
 
-bool ShotcutSettings::timelineCenterPlayhead() const
-{
-    return settings.value("timeline/centerPlayhead", false).toBool();
-}
-
-void ShotcutSettings::setTimelineCenterPlayhead(bool b)
-{
-    settings.setValue("timeline/centerPlayhead", b);
-    emit timelineCenterPlayheadChanged();
-}
-
 int ShotcutSettings::timelineTrackHeight() const
 {
     return qMin(settings.value("timeline/trackHeight", 50).toInt(), kMaximumTrackHeight);
@@ -643,11 +731,80 @@ void ShotcutSettings::setTimelineFramebufferWaveform(bool b)
     emit timelineFramebufferWaveformChanged();
 }
 
-QString ShotcutSettings::filterFavorite(const QString& filterName)
+int ShotcutSettings::audioReferenceTrack() const
+{
+    return settings.value("timeline/audioReferenceTrack", 0).toInt();
+}
+void ShotcutSettings::setAudioReferenceTrack(int track)
+{
+    settings.setValue("timeline/audioReferenceTrack", track);
+}
+
+double ShotcutSettings::audioReferenceSpeedRange() const
+{
+    return settings.value("timeline/audioReferenceSpeedRange", 0).toDouble();
+}
+void ShotcutSettings::setAudioReferenceSpeedRange(double range)
+{
+    settings.setValue("timeline/audioReferenceSpeedRange", range);
+}
+
+bool ShotcutSettings::timelinePreviewTransition() const
+{
+    return settings.value("timeline/previewTransition", true).toBool();
+}
+
+void ShotcutSettings::setTimelinePreviewTransition(bool b)
+{
+    settings.setValue("timeline/previewTransition", b);
+}
+
+void ShotcutSettings::setTimelineScrolling(ShotcutSettings::TimelineScrolling value)
+{
+    settings.remove("timeline/centerPlayhead");
+    settings.setValue("timeline/scrolling", value);
+    emit timelineScrollingChanged();
+}
+
+ShotcutSettings::TimelineScrolling ShotcutSettings::timelineScrolling() const
+{
+    if (settings.contains("timeline/centerPlayhead")
+            && settings.value("timeline/centerPlayhead").toBool())
+        return ShotcutSettings::TimelineScrolling::CenterPlayhead;
+    else
+        return ShotcutSettings::TimelineScrolling(settings.value("timeline/scrolling",
+                                                                 PageScrolling).toInt());
+}
+
+bool ShotcutSettings::timelineAutoAddTracks() const
+{
+    return settings.value("timeline/autoAddTracks", false).toBool();
+}
+
+void ShotcutSettings::setTimelineAutoAddTracks(bool b)
+{
+    if (b != timelineAutoAddTracks()) {
+        settings.setValue("timeline/autoAddTracks", b);
+        emit timelineAutoAddTracksChanged();
+    }
+}
+
+bool ShotcutSettings::timelineRectangleSelect() const
+{
+    return settings.value("timeline/rectangleSelect", true).toBool();
+}
+
+void ShotcutSettings::setTimelineRectangleSelect(bool b)
+{
+    settings.setValue("timeline/rectangleSelect", b);
+    emit timelineRectangleSelectChanged();
+}
+
+QString ShotcutSettings::filterFavorite(const QString &filterName)
 {
     return settings.value("filter/favorite/" + filterName, "").toString();
 }
-void ShotcutSettings::setFilterFavorite(const QString& filterName, const QString& value)
+void ShotcutSettings::setFilterFavorite(const QString &filterName, const QString &value)
 {
     settings.setValue("filter/favorite/" + filterName, value);
 }
@@ -708,17 +865,17 @@ void ShotcutSettings::setAskOutputFilter(bool b)
     emit askOutputFilterChanged();
 }
 
-bool ShotcutSettings::loudnessScopeShowMeter(const QString& meter) const
+bool ShotcutSettings::loudnessScopeShowMeter(const QString &meter) const
 {
     return settings.value("scope/loudness/" + meter, true).toBool();
 }
 
-void ShotcutSettings::setLoudnessScopeShowMeter(const QString& meter, bool b)
+void ShotcutSettings::setLoudnessScopeShowMeter(const QString &meter, bool b)
 {
     settings.setValue("scope/loudness/" + meter, b);
 }
 
-void ShotcutSettings::setMarkerColor(const QColor& color)
+void ShotcutSettings::setMarkerColor(const QColor &color)
 {
     settings.setValue("markers/color", color.name());
 }
@@ -728,12 +885,12 @@ QColor ShotcutSettings::markerColor() const
     return QColor(settings.value("markers/color", "green").toString());
 }
 
-void ShotcutSettings::setMarkersShowColumn(const QString& column, bool b)
+void ShotcutSettings::setMarkersShowColumn(const QString &column, bool b)
 {
     settings.setValue("markers/columns/" + column, b);
 }
 
-bool ShotcutSettings::markersShowColumn(const QString& column) const
+bool ShotcutSettings::markersShowColumn(const QString &column) const
 {
     return settings.value("markers/columns/" + column, true).toBool();
 }
@@ -811,7 +968,7 @@ QString ShotcutSettings::appDataLocation() const
         return QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
 }
 
-void ShotcutSettings::setAppDataForSession(const QString& location)
+void ShotcutSettings::setAppDataForSession(const QString &location)
 {
     // This is intended to be called when using a command line option
     // to set the AppData location.
@@ -820,7 +977,7 @@ void ShotcutSettings::setAppDataForSession(const QString& location)
         instance.reset(new ShotcutSettings(location));
 }
 
-void ShotcutSettings::setAppDataLocally(const QString& location)
+void ShotcutSettings::setAppDataLocally(const QString &location)
 {
     // This is intended to be called when using a GUI action to set the
     // the new AppData location.
@@ -828,7 +985,7 @@ void ShotcutSettings::setAppDataLocally(const QString& location)
     // Copy the existing settings if they exist.
     if (!QFile::exists(location + SHOTCUT_INI_FILENAME)) {
         QSettings newSettings(location + SHOTCUT_INI_FILENAME, QSettings::IniFormat);
-        foreach (const QString& key, settings.allKeys())
+        foreach (const QString &key, settings.allKeys())
             newSettings.setValue(key, settings.value(key));
         newSettings.sync();
     }
@@ -842,40 +999,41 @@ void ShotcutSettings::setAppDataLocally(const QString& location)
 QStringList ShotcutSettings::layouts() const
 {
     QStringList result;
-    for (const auto& s : settings.value("layout/layouts").toStringList()) {
+    for (const auto &s : settings.value("layout/layouts").toStringList()) {
         if (!s.startsWith("__"))
             result << s;
     }
     return result;
 }
 
-bool ShotcutSettings::setLayout(const QString& name, const QByteArray& geometry, const QByteArray& state)
+bool ShotcutSettings::setLayout(const QString &name, const QByteArray &geometry,
+                                const QByteArray &state)
 {
     bool isNew = false;
-    QStringList layouts = Settings.layouts();
+    QStringList layouts = this->layouts();
     if (layouts.indexOf(name) == -1) {
         isNew = true;
         layouts.append(name);
         settings.setValue("layout/layouts", layouts);
     }
-    settings.setValue(QString("layout/%1_%2").arg(name).arg("geometry"), geometry);
-    settings.setValue(QString("layout/%1_%2").arg(name).arg("state"), state);
+    settings.setValue(QString("layout/%1_%2").arg(name, "geometry"), geometry);
+    settings.setValue(QString("layout/%1_%2").arg(name, "state"), state);
     return isNew;
 }
 
-QByteArray ShotcutSettings::layoutGeometry(const QString& name)
+QByteArray ShotcutSettings::layoutGeometry(const QString &name)
 {
     QString key = QString("layout/%1_geometry").arg(name);
     return settings.value(key).toByteArray();
 }
 
-QByteArray ShotcutSettings::layoutState(const QString& name)
+QByteArray ShotcutSettings::layoutState(const QString &name)
 {
     QString key = QString("layout/%1_state").arg(name);
     return settings.value(key).toByteArray();
 }
 
-bool ShotcutSettings::removeLayout(const QString& name)
+bool ShotcutSettings::removeLayout(const QString &name)
 {
     QStringList list = layouts();
     int index = list.indexOf(name);
@@ -885,8 +1043,8 @@ bool ShotcutSettings::removeLayout(const QString& name)
             settings.remove("layout/layouts");
         else
             settings.setValue("layout/layouts", list);
-        settings.remove(QString("layout/%1_%2").arg(name).arg("geometry"));
-        settings.remove(QString("layout/%1_%2").arg(name).arg("state"));
+        settings.remove(QString("layout/%1_%2").arg(name, "geometry"));
+        settings.remove(QString("layout/%1_%2").arg(name, "state"));
         return true;
     }
     return false;
@@ -914,7 +1072,8 @@ void ShotcutSettings::setClearRecent(bool b)
 
 QString ShotcutSettings::projectsFolder() const
 {
-    return settings.value("projectsFolder", QStandardPaths::standardLocations(QStandardPaths::MoviesLocation)).toString();
+    return settings.value("projectsFolder",
+                          QStandardPaths::standardLocations(QStandardPaths::MoviesLocation)).toString();
 }
 
 void ShotcutSettings::setProjectsFolder(const QString &path)
@@ -922,6 +1081,53 @@ void ShotcutSettings::setProjectsFolder(const QString &path)
     settings.setValue("projectsFolder", path);
 }
 
+QString ShotcutSettings::audioInput() const
+{
+    QString defaultValue  = "default";
+#if defined(Q_OS_MAC) || defined(Q_OS_WIN)
+    for (const auto &deviceInfo : QMediaDevices::audioInputs()) {
+        defaultValue = deviceInfo.description();
+    }
+#endif
+    return settings.value("audioInput", defaultValue).toString();
+}
+
+void ShotcutSettings::setAudioInput(const QString &name)
+{
+    settings.setValue("audioInput", name);
+}
+
+QString ShotcutSettings::videoInput() const
+{
+    return settings.value("videoInput").toString();
+}
+
+void ShotcutSettings::setVideoInput(const QString &name)
+{
+    settings.setValue("videoInput", name);
+}
+
+QString ShotcutSettings::glaxnimatePath() const
+{
+    QDir dir(qApp->applicationDirPath());
+    return settings.value("glaxnimatePath", dir.absoluteFilePath("glaxnimate")).toString();
+}
+
+void ShotcutSettings::setGlaxnimatePath(const QString &path)
+{
+    settings.setValue("glaxnimatePath", path);
+}
+
+bool ShotcutSettings::exportRangeMarkers() const
+{
+    return settings.value("exportRangeMarkers", true).toBool();
+}
+
+void ShotcutSettings::setExportRangeMarkers(bool b)
+{
+    settings.setValue("exportRangeMarkers", b);
+}
+
 bool ShotcutSettings::proxyEnabled() const
 {
     return settings.value("proxy/enabled", false).toBool();
@@ -935,7 +1141,7 @@ void ShotcutSettings::setProxyEnabled(bool b)
 QString ShotcutSettings::proxyFolder() const
 {
     QDir dir(appDataLocation());
-    const char* subfolder = "proxies";
+    const char *subfolder = "proxies";
     if (!dir.cd(subfolder)) {
         if (dir.mkdir(subfolder))
             dir.cd(subfolder);
@@ -943,7 +1149,7 @@ QString ShotcutSettings::proxyFolder() const
     return settings.value("proxy/folder", dir.path()).toString();
 }
 
-void ShotcutSettings::setProxyFolder(const QString& path)
+void ShotcutSettings::setProxyFolder(const QString &path)
 {
     settings.setValue("proxy/folder", path);
 }
@@ -968,7 +1174,181 @@ void ShotcutSettings::setProxyUseHardware(bool b)
     settings.setValue("proxy/useHardware", b);
 }
 
+void ShotcutSettings::clearShortcuts(const QString &name)
+{
+    QString key = "shortcuts/" + name;
+    settings.remove(key);
+}
+
+void ShotcutSettings::setShortcuts(const QString &name, const QList<QKeySequence> &shortcuts)
+{
+    QString key = "shortcuts/" + name;
+    QString shortcutSetting;
+    if (shortcuts.size() > 0)
+        shortcutSetting += shortcuts[0].toString();
+    shortcutSetting += "||";
+    if (shortcuts.size() > 1)
+        shortcutSetting += shortcuts[1].toString();
+    settings.setValue(key, shortcutSetting);
+}
+
+QList<QKeySequence> ShotcutSettings::shortcuts(const QString &name)
+{
+    QString key = "shortcuts/" + name;
+    QList<QKeySequence> shortcuts;
+    QString shortcutSetting = settings.value(key, "").toString();
+    if (!shortcutSetting.isEmpty()) {
+        for (const QString &s : shortcutSetting.split("||"))
+            shortcuts << QKeySequence::fromString(s);
+    }
+    return shortcuts;
+}
+
+double ShotcutSettings::slideshowClipDuration(double defaultClipDuration) const
+{
+    return settings.value("slideshow/clipDuration", defaultClipDuration).toDouble();
+}
+
+void ShotcutSettings::setSlideshowClipDuration(double clipDuration)
+{
+    settings.setValue("slideshow/clipDuration", clipDuration);
+}
+
+int ShotcutSettings::slideshowAspectConversion(int defaultAspectConversion) const
+{
+    return settings.value("slideshow/aspectConversion", defaultAspectConversion).toInt();
+}
+
+void ShotcutSettings::setSlideshowAspectConversion(int aspectConversion)
+{
+    settings.setValue("slideshow/aspectConversion", aspectConversion);
+}
+
+int ShotcutSettings::slideshowZoomPercent(int defaultZoomPercent) const
+{
+    return settings.value("slideshow/zoomPercent", defaultZoomPercent).toInt();
+}
+
+void ShotcutSettings::setSlideshowZoomPercent(int zoomPercent)
+{
+    settings.setValue("slideshow/zoomPercent", zoomPercent);
+}
+
+double ShotcutSettings::slideshowTransitionDuration(double defaultTransitionDuration) const
+{
+    return settings.value("slideshow/transitionDuration", defaultTransitionDuration).toDouble();
+}
+
+void ShotcutSettings::setSlideshowTransitionDuration(double transitionDuration)
+{
+    settings.setValue("slideshow/transitionDuration", transitionDuration);
+}
+
+int ShotcutSettings::slideshowTransitionStyle(int defaultTransitionStyle) const
+{
+    return settings.value("slideshow/transitionStyle", defaultTransitionStyle).toInt();
+}
+
+void ShotcutSettings::setSlideshowTransitionStyle(int transitionStyle)
+{
+    settings.setValue("slideshow/transitionStyle", transitionStyle);
+}
+
+int ShotcutSettings::slideshowTransitionSoftness(int defaultTransitionStyle) const
+{
+    return settings.value("slideshow/transitionSoftness", defaultTransitionStyle).toInt();
+}
+
+void ShotcutSettings::setSlideshowTransitionSoftness(int transitionSoftness)
+{
+    settings.setValue("slideshow/transitionSoftness", transitionSoftness);
+}
+
+bool ShotcutSettings::keyframesDragScrub() const
+{
+    return settings.value("keyframes/dragScrub", false).toBool();
+}
+
+void ShotcutSettings::setKeyframesDragScrub(bool b)
+{
+    settings.setValue("keyframes/dragScrub", b);
+    emit keyframesDragScrubChanged();
+}
+
+void ShotcutSettings::setSubtitlesShowColumn(const QString &column, bool b)
+{
+    settings.setValue("subtitles/columns/" + column, b);
+}
+
+bool ShotcutSettings::subtitlesShowColumn(const QString &column) const
+{
+    return settings.value("subtitles/columns/" + column, true).toBool();
+}
+
+void ShotcutSettings::setSubtitlesTrackTimeline(bool b)
+{
+    settings.setValue("subtitles/trackTimeline", b);
+}
+
+bool ShotcutSettings::subtitlesTrackTimeline() const
+{
+    return settings.value("subtitles/trackTimeline", true).toBool();
+}
+
+void ShotcutSettings::setSubtitlesShowPrevNext(bool b)
+{
+    settings.setValue("subtitles/showPrevNext", b);
+}
+
+bool ShotcutSettings::subtitlesShowPrevNext() const
+{
+    return settings.value("subtitles/showPrevNext", true).toBool();
+}
+
+void ShotcutSettings::setNotesZoom(int zoom)
+{
+    settings.setValue("notes/zoom", zoom);
+}
+
+int ShotcutSettings::notesZoom() const
+{
+    return settings.value("notes/zoom", 0).toInt();
+}
+
+void ShotcutSettings::reset()
+{
+    for (auto &key : settings.allKeys()) {
+        settings.remove(key);
+    }
+}
+
 int ShotcutSettings::undoLimit() const
 {
-    return settings.value("undoLimit", 1000).toInt();
+    return settings.value("undoLimit", 50).toInt();
+}
+
+bool ShotcutSettings::warnLowMemory() const
+{
+    return settings.value("warnLowMemory", true).toBool();
+}
+
+int ShotcutSettings::backupPeriod() const
+{
+    return settings.value("backupPeriod", 24 * 60).toInt();
+}
+
+void ShotcutSettings::setBackupPeriod(int minutes)
+{
+    settings.setValue("backupPeriod", minutes);
+}
+
+mlt_time_format ShotcutSettings::timeFormat() const
+{
+    return (mlt_time_format)settings.value("timeFormat", mlt_time_smpte_df).toInt();
+}
+
+void ShotcutSettings::setTimeFormat(int format)
+{
+    settings.setValue("timeFormat", format);
+    emit timeFormatChanged();
 }
